from cpl_core.dependency_injection import ServiceProviderABC
from cpl_discord.service import DiscordBotServiceABC

from bot_data.abc.history_table_abc import HistoryTableABC


class AutoRoleHistory(HistoryTableABC):
    def __init__(
        self,
        server: int,
        channel_id: int,
        dc_message_id: int,
        deleted: bool,
        date_from: str,
        date_to: str,
        id=0,
    ):
        HistoryTableABC.__init__(self)

        self._auto_role_id = id
        self._server = server
        self._discord_channel_id = channel_id
        self._discord_message_id = dc_message_id

        self._deleted = deleted
        self._date_from = date_from
        self._date_to = date_to

    @property
    def id(self) -> int:
        return self._auto_role_id

    @property
    def server(self) -> int:
        return self._server

    @property
    def discord_channel_id(self) -> int:
        return self._discord_channel_id

    @property
    @ServiceProviderABC.inject
    def discord_channel_name(self, bot: DiscordBotServiceABC) -> str:
        channel = bot.get_channel(self.discord_channel_id)
        return None if channel is None else channel.name

    @property
    def discord_message_id(self) -> int:
        return self._discord_message_id
