import discord
from cpl_core.database.context import DatabaseContextABC
from cpl_discord.service import DiscordBotServiceABC
from cpl_translation import TranslatePipe
from discord import ui, TextStyle

from bot_core.abc.message_service_abc import MessageServiceABC
from bot_core.logging.command_logger import CommandLogger
from bot_data.model.technician_config import TechnicianConfig


class BugReportForm(ui.Modal):
    description = ui.TextInput(label="Report a bug", required=True, style=TextStyle.long)

    def __init__(
        self,
        technician_config: TechnicianConfig,
        bot: DiscordBotServiceABC,
        db: DatabaseContextABC,
        logger: CommandLogger,
        message_service: MessageServiceABC,
        t: TranslatePipe,
    ):
        ui.Modal.__init__(self, title=t.transform("modules.base.bug.title"))

        self._technician_config = technician_config
        self._bot = bot
        self._db = db
        self._message_service = message_service
        self._logger = logger
        self._t = t

        self.description.label = t.transform("modules.base.bug.label")

    async def on_submit(self, interaction: discord.Interaction):
        self._logger.debug(__name__, f"Started bug report form")

        for t in self._technician_config.technician_ids:
            member = self._bot.get_user(t)
            await self._message_service.send_dm_message(
                self._t.transform("modules.base.bug.message").format(interaction.user.mention, self.description.value),
                member,
                without_tracking=True,
            )

        await self._message_service.send_interaction_msg(interaction, self._t.transform("modules.base.bug.response"))
        self._logger.trace(__name__, f"Finished bug report form")
