import discord
from cpl_core.dependency_injection import ServiceProviderABC
from cpl_query.extension import List
from discord import Interaction, app_commands
from discord.app_commands import Transformer, Choice

from bot_core.abc.client_utils_abc import ClientUtilsABC


class VoiceChannelTransformer(Transformer):
    async def transform(self, interaction: Interaction, value: str, /) -> discord.VoiceChannel:
        voice_channel = (
            List(discord.VoiceChannel, interaction.guild.voice_channels)
            .where(lambda x: str(x.id) == value)
            .first_or_default()
        )
        return voice_channel

    async def autocomplete(self, interaction: Interaction, current: str, /) -> list[Choice[str]]:
        @ServiceProviderABC.inject
        def get_client_utils(client_utils: ClientUtilsABC) -> ClientUtilsABC:
            return client_utils

        voice_channels = List(discord.Role, interaction.guild.voice_channels).where(lambda x: len(x.members) > 0)
        return [
            app_commands.Choice(
                name=f"{vc.name}" if vc.category is None else f"{vc.name}: {vc.category.name}",
                value=vc.name,
            )
            for vc in get_client_utils().get_auto_complete_list(voice_channels, current, lambda x: x.name)
        ]
